@@ -1,12 +1,17 @@
-__version__ = "5.0.14"
+__version__ = "5.0.18"
 
-from .logger import LogLevelEnum, logger_init, log_llm_error
 from .models import (
     MTRSLabelEnum,
     ChatItem,
     InnerContextItem,
     OuterContextItem,
     ReplicaItem,
+    Chat,
+    Context,
+    ChatMessage,
+    AIMessage,
+    HumanMessage,
+    MiscMessage,
 )
 from .models.widget import Widget
 from .file_storage import FileStorage, ResourceId
@@ -19,4 +24,6 @@ from .models.tracks import TrackInfo, DomainInfo
 from .api.chat_manager_api import ChatManagerAPI
 from .api.content_interpreter_api import ContentInterpreterAPI, Interpretation
 from .api.content_interpreter_remote_api import ContentInterpreterRemoteAPI
-from .api.text_processor_api import TextProcessorAPI
+from .api.text_generator_api import TextGeneratorAPI
+from .api.classifier_api import ClassifierAPI
+from .api.critic_api import CriticAPI
