@@ -3,6 +3,7 @@ import json
 import os
 from datetime import datetime
 from pathlib import Path
+from typing import Iterable
 
 
 def make_session_id() -> str:
@@ -36,17 +37,20 @@ def try_parse_int(text: str) -> int | None:
     except (ValueError, TypeError):
         return None
 
+
 def try_parse_float(text: str) -> float | None:
     try:
         return float(text)
     except (ValueError, TypeError):
         return None
 
+
 def try_parse_bool(v: str | bool) -> bool:
     if isinstance(v, bool):
         return v
     return v.lower() in ("yes", "true", "t", "1")
 
+
 def pretty_line(text: str, cut_count: int = 100) -> str:
     if len(text) > 100:
         text_cut = text[:cut_count]
@@ -56,3 +60,10 @@ def pretty_line(text: str, cut_count: int = 100) -> str:
         text_pretty = text
     text_pretty = text_pretty.replace("\n", "\\n")
     return text_pretty
+
+
+def first_nonnull(obj: Iterable):
+    for elem in obj:
+        if elem:
+            return elem
+    return None
